//
//  MyExtensions.h
//  Pediabase
//
//  Created by Conor Dearden on 8/10/06.
//  Copyright 2006 Chiguire LLC. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#pragma mark Extensions Apple Classes 



@interface NSString (NSStringExtensions)
+ (NSString *)stringFromFile:(NSString *)aPath;

- (BOOL)isNotEmpty;
- (float)myFloatValue;
- (NSInteger)myIntValue;
- (BOOL)isEAN;
- (NSString *)stringByRemovingDashes;

- (NSUInteger)countOccurrencesOfString:(NSString *)subString;
- (BOOL)containsString:(NSString *)subString;
- (NSString *)stringByRemovingPrefix:(NSString *)subString;
- (NSString *)stringByRemovingSuffix:(NSString *)subString;

- (NSString *)stringByResolvingAliasInPath;

+ (NSString *)timeStringWithSeconds:(NSUInteger)seconds;
- (NSUInteger)secondsAsTimeString;


	//Parsing
- (NSString *)stringBetween:(NSString *)startString and:(NSString *)endString;
- (NSString *)stringBetween:(NSString *)startString and:(NSString *)endString startingFrom:(NSString *)primeString;
- (NSArray *)stringsBetween:(NSString *)startString and:(NSString *)endString;
- (NSString *)substringFromString:(NSString *)stringToFind;

	//sorting
- (NSComparisonResult)lastNameCompare:(NSString *)anotherString;
- (NSComparisonResult)lccCompare:(NSString *)anotherString;
- (NSComparisonResult)priceCompare:(NSString *)anotherString;
- (NSComparisonResult)deweyCompare:(NSString *)anotherString;
- (NSComparisonResult)ignoringArticleCompare:(NSString *)anotherString;
- (NSComparisonResult)caseInsensitiveNumericCompare:(NSString *)anotherString;
- (NSComparisonResult)localizedIdentifierCompare:(NSString *)anotherString;
//- (BOOL)containsString:(NSString)aString;

	//HTML cleaning
- (NSString *)stringByCleaningHTML;
- (NSString *)stringByRemovingHTML;
- (NSString *)stringByReplacingHTMLEncoding;
- (NSString *)stringByRemovingLeadingAndTrailingSpaces;
- (NSString *)stringByRemovingLeadingAndTrailingQuotes;
- (NSString *)stringByMovingEndingArticles;
- (NSString *)stringByRemovingNewLines;

- (NSString *)substringToString:(NSString *)section;
- (NSString *)titleCaseString;

@end


#pragma mark -
@interface NSNull (NSNullExtensions)
- (BOOL)isNotEmpty;
@end


#pragma mark -
@interface NSDate (NSDateExtensions)
+ (NSDate *)myDateWithNaturalLanguageString:(NSString *)aString;
+ (NSDate *)myDateWithNaturalLanguageString:(NSString *)aString locale:(NSDictionary *)aLocale;

+ (NSDate *)dateFromYearMonthDayString:(NSString *)aString;

- (NSDate *)dateAtBeginningOfDay;
- (NSDate *)dateAtEndOfDay;
- (NSDate *)dateAtBeginningOfYear;
- (NSDate *)dateAtEndOfYear;
- (BOOL)isNotEmpty;
@end


#pragma mark -
@interface NSDateFormatter (NSDateFormatterExtensions)
+ (NSDate *)dateFromMacStandard:(NSString *)aString;
@end


#pragma mark -
@interface NSData (NSDataExtensions)
- (BOOL)isNotEmpty;
- (NSString *)base64String;
- (NSString *)string;
- (id)propertyList;
- (id)JSONValue;
@end

#pragma mark -
@interface NSNumber (NSNumberExtensions)
- (NSComparisonResult)caseInsensitiveNumericCompare:(NSNumber *)anotherNumber;
- (BOOL)isNotEmpty;
- (NSInteger)myFloatValue;
@end

#pragma mark -
@interface NSDictionary (NSDictionaryExtensions)
- (NSData *)propertyListData;
- (NSComparisonResult)localizedIdentifierCompare:(NSDictionary *)anotherDictionary;
@end

#pragma mark -
@interface NSMutableDictionary (NSMutableDictionaryExtensions)
- (void)addString:(NSString *)additionalString forKey:(NSString *)aKey; //append with ", " only if unique
@end


#pragma mark -
@interface NSObject (NSObjectExtensions)
- (MOCollection *)observedObject;  //For NSTreeControler hidden method to get the real object instead of proxy 
@end


#pragma mark -
@interface NSBezierPath (NSBezierPathExtensions)
+(NSBezierPath*)bezierPathWithRoundRectInRect:(NSRect)rect radius:(float) radius;
@end
	

#pragma mark -
@interface NSException (NSExceptionExtensions)
- (void)printStackTrace;	
@end


#pragma mark -
@interface NSToolbar (NSToolbarExtensions)
- (NSToolbarItem *)itemWithIdentifier:(NSString *)identifier;
@end

#pragma mark -
@interface NSTableView (NSTableViewExtensions)
- (void)drawStripesInRect:(NSRect)clipRect;
@end 

#pragma mark -
@interface NSMigrationManager (Workaround)
+ (void)addRelationshipMigrationMethodIfMissing;
@end

#pragma mark -
@interface NSArray (NSArrayExtensions)
- (id)firstObject;
@end

#pragma mark -
@interface NSFont (NSFontExtensions)
- (NSFont *)italicVersion;
- (NSFont *)boldVersion;
@end

#pragma mark -
@interface NSImage (NSImageExtensions)
- (NSComparisonResult)compare:(NSImage *)anotherImage;
+ (NSImage *)imageWithStringURL:(NSString *)stringURL;
@end

#pragma mark -
@interface NSFileManager (NSFileManagerExtensions)
+ (NSString *)megabytesStringForPath:(NSString *)aPath;
@end

@interface NSBundle (NSBundleExtensions)
+ (NSArray *)myLoadNibNamed:(NSString *)aName owner:(id)owner;
@end


@interface NSURLSession (NSURLSessionExtensions)
+ (NSData *)sendSynchronousRequest:(NSURLRequest *)request returningResponse:(NSURLResponse **)response error:(NSError **)error;
@end


/*
#pragma mark -
@interface NSBezierPath (NSBezierPathPrivate)
+ (void)drawLineFrom:(NSPoint)start to:(NSPoint)end;
@end */
